@@ -5,7 +5,6 @@ use crate::{
         PacketMetaData,
         Store
     },
-    Storage,
     uuid::Uuid
 };
 use std::collections::BTreeMap;
@@ -57,8 +56,7 @@ mod tests {
     mod add {
         use crate::{
             mem::open,
-            store::{ Packet, GroupDefaults },
-            Storage
+            store::{ Packet, GroupDefaults }
         };
 
         #[test]
@@ -230,8 +228,7 @@ mod tests {
     mod get {
         use crate::{
             mem::open,
-            store::Packet,
-            Storage
+            store::Packet
         };
 
         #[test]
@@ -279,8 +276,7 @@ mod tests {
     mod del {
         use crate::{
             mem::open,
-            store::Packet,
-            Storage
+            store::Packet
         };
 
         #[test]
@@ -345,8 +341,7 @@ mod tests {
             store::{
                 GroupDefaults,
                 Packet
-            },
-            Storage
+            }
         };
 
         #[test]
@@ -380,14 +375,37 @@ mod tests {
 
     }
 
+    mod delete_group_defaults {
+        use crate::{
+            mem::open,
+            store::{
+                GroupDefaults,
+                Packet
+            }
+        };
+
+        #[test]
+        #[test]
+        fn should_update_existing_group() {
+            let mut store = open();
+            store.update_group_defaults(1, &GroupDefaults{ max_byte_size: Some(10) });
+            store.add(&Packet::new(1, "foo".to_string())).expect("Could not add message");
+            let group = store.groups_map.get(&1).expect("Could not find defaults");
+            assert_eq!(Some(10), group.max_byte_size);
+            store.delete_group_defaults(1);
+            assert!(store.group_defaults.get(&1).is_none());
+            let group = store.groups_map.get(&1).expect("Could not find defaults");
+            assert_eq!(None, group.max_byte_size);
+        }
+    }
+
     mod update_store_defaults {
         use crate::{
             mem::open,
             store::{
                 StoreDefaults,
                 Packet
-            },
-            Storage
+            }
         };
 
         #[test]
@@ -416,8 +434,7 @@ mod tests {
             mem::open,
             store::{
                 Packet
-            },
-            Storage
+            }
         };
 
         #[test]
