@@ -1,6 +1,5 @@
 use crate::{
     Keeper,
-    Storage,
     uuid::{
         UuidManager,
         Uuid
@@ -118,6 +117,32 @@ pub struct Store<Db: Keeper> {
 
 impl<Db: Keeper> Store<Db> {
 
+    pub fn open(db: Db) -> Store<Db> {        
+        let mut store = Store {
+            max_byte_size: None,
+            byte_size: 0,
+            group_defaults: BTreeMap::new(),
+            uuid_manager: UuidManager::default(),
+            db,
+            id_to_group_map: BTreeMap::new(),
+            groups_map: BTreeMap::new(),
+            msgs_inserted: 0,
+            msgs_deleted: 0,
+            msgs_burned: 0
+        };
+        let mut data = store.db.fetch();
+        data.sort();
+        data.iter().for_each(|data| {
+            store.insert_data(&data).expect("Could not insert data");
+        });
+        store
+    }
+
+    /// A method for reseting the inserted messages count
+    pub fn clear_msgs_inserted_count(&mut self) {
+        self.msgs_inserted = 0;
+    }
+
     fn inc_msgs_inserted_count(&mut self) {
         if self.msgs_inserted == i32::MAX {
             self.msgs_inserted = 1;
@@ -126,6 +151,11 @@ impl<Db: Keeper> Store<Db> {
         }
     }
 
+    /// A method for reseting the burned messages count
+    pub fn clear_msgs_burned_count(&mut self) {
+        self.msgs_burned = 0;
+    }
+
     fn inc_msgs_burned_count(&mut self) {
         if self.msgs_burned == i32::MAX {
             self.msgs_burned = 1;
@@ -134,6 +164,11 @@ impl<Db: Keeper> Store<Db> {
         }
     }
 
+    /// A method for reseting the deleted messages count
+    pub fn clear_msgs_deleted_count(&mut self) {
+        self.msgs_deleted = 0;
+    }
+
     fn inc_msgs_deleted(&mut self, msgs_deleted: i32) {
         let diff = (i32::MAX - self.msgs_deleted) - msgs_deleted;
         if diff < 0 {
@@ -319,46 +354,6 @@ impl<Db: Keeper> Store<Db> {
         Ok(())
     }
 
-}
-
-impl<Db: Keeper> Storage<Db> for Store<Db> {
-
-    fn open(db: Db) -> Store<Db> {        
-        let mut store = Store {
-            max_byte_size: None,
-            byte_size: 0,
-            group_defaults: BTreeMap::new(),
-            uuid_manager: UuidManager::default(),
-            db,
-            id_to_group_map: BTreeMap::new(),
-            groups_map: BTreeMap::new(),
-            msgs_inserted: 0,
-            msgs_deleted: 0,
-            msgs_burned: 0
-        };
-        let mut data = store.db.fetch();
-        data.sort();
-        data.iter().for_each(|data| {
-            store.insert_data(&data).expect("Could not insert data");
-        });
-        store
-    }
-
-    /// A method for reseting the inserted messages count
-    fn clear_msgs_inserted_count(&mut self) {
-        self.msgs_inserted = 0;
-    }
-
-    /// A method for reseting the burned messages count
-    fn clear_msgs_burned_count(&mut self) {
-        self.msgs_burned = 0;
-    }
-
-    /// A method for reseting the deleted messages count
-    fn clear_msgs_deleted_count(&mut self) {
-        self.msgs_deleted = 0;
-    }
-
     /// Adds a msg to the store
     /// 
     /// The message itself is written to disk as well as metadata about the message
@@ -382,14 +377,14 @@ impl<Db: Keeper> Storage<Db> for Store<Db> {
     /// 
     /// # Examples
     /// ```
-    /// use msg_store::{ Packet, open, Storage };
+    /// use msg_store::{ Packet, open };
     /// 
     /// let mut store = open();
     /// let uuid = store.add(&Packet::new(1, "my message".to_string())).expect("Could not add msg");
     /// 
     /// ```
     /// 
-    fn add(&mut self, packet: &Packet) -> Result<Uuid, String> {
+    pub fn add(&mut self, packet: &Packet) -> Result<Uuid, String> {
 
         let msg_byte_size = packet.msg.len() as i32;
 
@@ -436,14 +431,14 @@ impl<Db: Keeper> Storage<Db> for Store<Db> {
     /// 
     /// # Examples
     /// ```
-    /// use msg_store::{ Packet, open, Storage };
+    /// use msg_store::{ Packet, open };
     /// 
     /// let mut store = open();
     /// let uuid = store.add(&Packet::new(1, "my message".to_string())).expect("Could not add msg");
     /// store.del(&uuid).expect("Could not remove msg");
     /// 
     /// ```
-    fn del(&mut self, uuid: &Uuid) -> Result<(), String> {
+    pub fn del(&mut self, uuid: &Uuid) -> Result<(), String> {
         let mut remove_group = false;
         let priority = match self.id_to_group_map.get(&uuid) {
             Some(priority) => priority,
@@ -489,7 +484,7 @@ impl<Db: Keeper> Storage<Db> for Store<Db> {
     /// 
     /// # Examples
     /// ```
-    /// use msg_store::{ Packet, open, Storage };
+    /// use msg_store::{ Packet, open };
     /// 
     /// let mut store = open();
     /// let uuid = store.add(&Packet::new(1, "my message".to_string())).expect("Could not add msg");
@@ -503,7 +498,7 @@ impl<Db: Keeper> Storage<Db> for Store<Db> {
     /// assert!(my_message.is_some());
     /// 
     /// ```
-    fn get(&mut self, uuid: Option<Uuid>, priority: Option<i32>) -> Option<StoredPacket> {
+    pub fn get(&mut self, uuid: Option<Uuid>, priority: Option<i32>) -> Option<StoredPacket> {
         match uuid {
             Some(uuid) => match self.db.get(&uuid) {
                 Some(msg) => Some(StoredPacket {
@@ -555,7 +550,7 @@ impl<Db: Keeper> Storage<Db> for Store<Db> {
     /// use msg_store::{
     ///     Packet,
     ///     store::GroupDefaults,
-    ///     open, Storage
+    ///     open
     /// };
     /// 
     /// let mut store = open();
@@ -569,7 +564,7 @@ impl<Db: Keeper> Storage<Db> for Store<Db> {
     /// assert_eq!(3, store.byte_size); 
     /// 
     /// ```
-    fn update_group_defaults(&mut self, priority: i32, defaults: &GroupDefaults) {
+    pub fn update_group_defaults(&mut self, priority: i32, defaults: &GroupDefaults) {
         self.group_defaults.insert(priority, defaults.clone());
         if let Some(mut group) = self.groups_map.remove(&priority) {
             group.update_from_config(defaults.clone());
@@ -578,6 +573,40 @@ impl<Db: Keeper> Storage<Db> for Store<Db> {
         }
     }
 
+    /// Removes the defaults for a priority group
+    /// 
+    /// # Example
+    /// ```
+    /// use msg_store::{
+    ///     Packet,
+    ///     store::GroupDefaults,
+    ///     open
+    /// };
+    /// 
+    /// let mut store = open();
+    /// store.update_group_defaults(1, &GroupDefaults{ max_byte_size: Some(6) });
+    /// store.add(&Packet::new(1, "foo".to_string())).expect("Could not add msg");
+    /// store.add(&Packet::new(1, "bar".to_string())).expect("Could not add msg");
+    /// 
+    /// let group_1 = store.groups_map.get(&1).expect("Could not find group");
+    /// assert_eq!(Some(6), group_1.max_byte_size);
+    /// 
+    /// // Now for the removal of the defaults
+    /// store.delete_group_defaults(1);
+    /// 
+    /// let group_1 = store.groups_map.get(&1).expect("Could not find group");
+    /// 
+    /// assert_eq!(None, group_1.max_byte_size);
+    /// assert!(store.group_defaults.get(&1).is_none()); 
+    /// 
+    /// ```
+    pub fn delete_group_defaults(&mut self, priority: i32) {
+        self.group_defaults.remove(&priority);
+        if let Some(group) = self.groups_map.get_mut(&priority) {
+            group.max_byte_size = None;
+        }
+    }
+
     /// Updates the defaults for the store
     /// 
     /// The method takes a StoreDefaults struct which contains a member: max_byte_size.
@@ -592,7 +621,7 @@ impl<Db: Keeper> Storage<Db> for Store<Db> {
     /// use msg_store::{
     ///     Packet,
     ///     store::StoreDefaults,
-    ///     open, Storage
+    ///     open
     /// };
     /// 
     /// let mut store = open();
@@ -606,9 +635,9 @@ impl<Db: Keeper> Storage<Db> for Store<Db> {
     /// assert_eq!(3, store.byte_size); 
     /// 
     /// ```
-    fn update_store_defaults(&mut self, defaults: &StoreDefaults) {
+    pub fn update_store_defaults(&mut self, defaults: &StoreDefaults) {
         self.max_byte_size = defaults.max_byte_size;
         self.prune_store(None, i32::MAX, 0)
     }
 
-}
\ No newline at end of file
+}
